==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_functions/gridrequest/MULTIADDON_FILTERS.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="MADDON_FILTER" maxOccurs="unbounded">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
 *                 &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 &lt;attribute name="RPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *                 &lt;attribute name="LPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *                 &lt;attribute name="JOINER" type="{http://schemas.datastream.net/MP_functions/GridRequest}AND_OR" />
 *                 &lt;attribute name="SEQNUM" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "maddon_FILTER"
})
@XmlRootElement(name = "MULTIADDON_FILTERS")
public class MULTIADDON_FILTERS {

    @XmlElement(name = "MADDON_FILTER", required = true)
    protected List<MULTIADDON_FILTERS.MADDON_FILTER> maddon_FILTER;

    /**
     * Gets the value of the maddonFILTER property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the maddonFILTER property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMADDON_FILTER().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MULTIADDON_FILTERS.MADDON_FILTER }
     * 
     * 
     */
    public List<MULTIADDON_FILTERS.MADDON_FILTER> getMADDON_FILTER() {
        if (maddon_FILTER == null) {
            maddon_FILTER = new ArrayList<MULTIADDON_FILTERS.MADDON_FILTER>();
        }
        return this.maddon_FILTER;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
     *       &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       &lt;attribute name="RPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *       &lt;attribute name="LPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *       &lt;attribute name="JOINER" type="{http://schemas.datastream.net/MP_functions/GridRequest}AND_OR" />
     *       &lt;attribute name="SEQNUM" type="{http://www.w3.org/2001/XMLSchema}integer" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class MADDON_FILTER {

        @XmlAttribute(name = "ALIAS_NAME")
        protected String alias_NAME;
        @XmlAttribute(name = "OPERATOR")
        protected String operator;
        @XmlAttribute(name = "VALUE")
        protected String value;
        @XmlAttribute(name = "RPAREN")
        protected String rparen;
        @XmlAttribute(name = "LPAREN")
        protected String lparen;
        @XmlAttribute(name = "JOINER")
        protected AND_OR joiner;
        @XmlAttribute(name = "SEQNUM")
        protected BigInteger seqnum;

        /**
         * Gets the value of the alias_NAME property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getALIAS_NAME() {
            return alias_NAME;
        }

        /**
         * Sets the value of the alias_NAME property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setALIAS_NAME(String value) {
            this.alias_NAME = value;
        }

        /**
         * Gets the value of the operator property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getOPERATOR() {
            return operator;
        }

        /**
         * Sets the value of the operator property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setOPERATOR(String value) {
            this.operator = value;
        }

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVALUE() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVALUE(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the rparen property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRPAREN() {
            return rparen;
        }

        /**
         * Sets the value of the rparen property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRPAREN(String value) {
            this.rparen = value;
        }

        /**
         * Gets the value of the lparen property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLPAREN() {
            return lparen;
        }

        /**
         * Sets the value of the lparen property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLPAREN(String value) {
            this.lparen = value;
        }

        /**
         * Gets the value of the joiner property.
         * 
         * @return
         *     possible object is
         *     {@link AND_OR }
         *     
         */
        public AND_OR getJOINER() {
            return joiner;
        }

        /**
         * Sets the value of the joiner property.
         * 
         * @param value
         *     allowed object is
         *     {@link AND_OR }
         *     
         */
        public void setJOINER(AND_OR value) {
            this.joiner = value;
        }

        /**
         * Gets the value of the seqnum property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getSEQNUM() {
            return seqnum;
        }

        /**
         * Sets the value of the seqnum property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setSEQNUM(BigInteger value) {
            this.seqnum = value;
        }

    }

}

==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_functions/gridrequest/MULTIADDON_FILTERS.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="MADDON_FILTER" maxOccurs="unbounded">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
 *                 &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 &lt;attribute name="RPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *                 &lt;attribute name="LPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *                 &lt;attribute name="JOINER" type="{http://schemas.datastream.net/MP_functions/GridRequest}AND_OR" />
 *                 &lt;attribute name="SEQNUM" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "maddon_FILTER"
})
@XmlRootElement(name = "MULTIADDON_FILTERS")
public class MULTIADDON_FILTERS {

    @XmlElement(name = "MADDON_FILTER", required = true)
    protected List<MULTIADDON_FILTERS.MADDON_FILTER> maddon_FILTER;

    /**
     * Gets the value of the maddonFILTER property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the maddonFILTER property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMADDON_FILTER().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MULTIADDON_FILTERS.MADDON_FILTER }
     * 
     * 
     */
    public List<MULTIADDON_FILTERS.MADDON_FILTER> getMADDON_FILTER() {
        if (maddon_FILTER == null) {
            maddon_FILTER = new ArrayList<MULTIADDON_FILTERS.MADDON_FILTER>();
        }
        return this.maddon_FILTER;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;attribute name="ALIAS_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       &lt;attribute name="OPERATOR" type="{http://schemas.datastream.net/MP_functions/GridRequest}OPERATOR_TYPE" />
     *       &lt;attribute name="VALUE" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       &lt;attribute name="RPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *       &lt;attribute name="LPAREN" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
     *       &lt;attribute name="JOINER" type="{http://schemas.datastream.net/MP_functions/GridRequest}AND_OR" />
     *       &lt;attribute name="SEQNUM" type="{http://www.w3.org/2001/XMLSchema}integer" />
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class MADDON_FILTER {

        @XmlAttribute(name = "ALIAS_NAME")
        protected String alias_NAME;
        @XmlAttribute(name = "OPERATOR")
        protected String operator;
        @XmlAttribute(name = "VALUE")
        protected String value;
        @XmlAttribute(name = "RPAREN")
        protected String rparen;
        @XmlAttribute(name = "LPAREN")
        protected String lparen;
        @XmlAttribute(name = "JOINER")
        protected AND_OR joiner;
        @XmlAttribute(name = "SEQNUM")
        protected BigInteger seqnum;

        /**
         * Obtient la valeur de la propriété alias_NAME.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getALIAS_NAME() {
            return alias_NAME;
        }

        /**
         * Définit la valeur de la propriété alias_NAME.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setALIAS_NAME(String value) {
            this.alias_NAME = value;
        }

        /**
         * Obtient la valeur de la propriété operator.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getOPERATOR() {
            return operator;
        }

        /**
         * Définit la valeur de la propriété operator.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setOPERATOR(String value) {
            this.operator = value;
        }

        /**
         * Obtient la valeur de la propriété value.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getVALUE() {
            return value;
        }

        /**
         * Définit la valeur de la propriété value.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setVALUE(String value) {
            this.value = value;
        }

        /**
         * Obtient la valeur de la propriété rparen.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getRPAREN() {
            return rparen;
        }

        /**
         * Définit la valeur de la propriété rparen.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setRPAREN(String value) {
            this.rparen = value;
        }

        /**
         * Obtient la valeur de la propriété lparen.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getLPAREN() {
            return lparen;
        }

        /**
         * Définit la valeur de la propriété lparen.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setLPAREN(String value) {
            this.lparen = value;
        }

        /**
         * Obtient la valeur de la propriété joiner.
         * 
         * @return
         *     possible object is
         *     {@link AND_OR }
         *     
         */
        public AND_OR getJOINER() {
            return joiner;
        }

        /**
         * Définit la valeur de la propriété joiner.
         * 
         * @param value
         *     allowed object is
         *     {@link AND_OR }
         *     
         */
        public void setJOINER(AND_OR value) {
            this.joiner = value;
        }

        /**
         * Obtient la valeur de la propriété seqnum.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getSEQNUM() {
            return seqnum;
        }

        /**
         * Définit la valeur de la propriété seqnum.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setSEQNUM(BigInteger value) {
            this.seqnum = value;
        }

    }

}
